/////////////////////////////////////////////////////////////////////////////
//
// Written by Igor Tolmachev (support@itsamples.com)
// Copyright (c) 2017 Igor Tolmachev.
//
// This code may be used in compiled form in any way you desire. This
// source file may be redistributed by any means PROVIDING it is 
// not sold for profit without the authors written consent, and 
// providing that this notice and the authors name is included. 
//
// This file is provided "as is" with no expressed or implied warranty.
// The author accepts no liability if it causes any damage to you or your
// computer whatsoever. It's free, so don't hassle me about it.
//
// Beware of bugs.
//

// ViewDlg.cpp : implementation of the CViewDlg class
//
/////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "resource.h"

#include "ViewDlg.h"

CViewDlg::CViewDlg(CString strFilePath) :
    m_strFilePath(strFilePath)
{
}

LRESULT CViewDlg::OnInitDialog(UINT /*uMsg*/, WPARAM /*wParam*/, LPARAM /*lParam*/, BOOL& /*bHandled*/)
{
    CenterWindow();

    DlgResize_Init();

    m_FilePreview.SubclassWindow(GetDlgItem(IDC_STATIC_PREVIEW));
    m_FilePreview.SetBytesPerLine(10);
    m_FilePreview.SetEmptyMessage(_T("No data to display"));

    ShowFile(m_strFilePath);

    CMessageLoop* pLoop = _Module.GetMessageLoop();
    if(pLoop)
        pLoop->AddMessageFilter(this);

    return TRUE;
}

void CViewDlg::ShowFile(CString strFilePath)
{
    if(!strFilePath.IsEmpty())
    {
        m_FilePreview.SetFile(strFilePath);
        SetWindowText(strFilePath);
    }
}

BOOL CViewDlg::PreTranslateMessage(MSG* pMsg)
{
    if (pMsg->message == WM_KEYDOWN)
    {
        switch (pMsg->wParam) 
        {
        case VK_UP:
            ::SendMessage(m_FilePreview.m_hWnd, WM_VSCROLL, MAKEWPARAM(SB_LINEUP, 0), NULL);
            break;
        case VK_DOWN:
            ::SendMessage(m_FilePreview.m_hWnd, WM_VSCROLL, MAKEWPARAM(SB_LINEDOWN, 0), NULL);
            break;
        case VK_NEXT:
            ::SendMessage(m_FilePreview.m_hWnd, WM_VSCROLL, MAKEWPARAM(SB_PAGEDOWN, 0), NULL);
            break;
        case VK_PRIOR:
            ::SendMessage(m_FilePreview.m_hWnd, WM_VSCROLL, MAKEWPARAM(SB_PAGEUP, 0), NULL);
            break;
        case VK_HOME:
            ::SendMessage(m_FilePreview.m_hWnd, WM_VSCROLL, MAKEWPARAM(SB_TOP, 0), NULL);
            break;
        case VK_END:
            ::SendMessage(m_FilePreview.m_hWnd, WM_VSCROLL, MAKEWPARAM(SB_BOTTOM, 0), NULL);
            break;
        case VK_ESCAPE:
            ShowWindow(SW_HIDE);
            break;
        }
    }

    return FALSE;
}

LRESULT CViewDlg::OnMouseWheel(UINT /*uMsg*/, WPARAM wParam, LPARAM /*lParam*/, BOOL& bHandled)
{
    short nWheel = HIWORD(wParam);
    if(nWheel > 0)
        ::SendMessage(m_FilePreview.m_hWnd, WM_VSCROLL, MAKEWPARAM(SB_LINEUP, 0), NULL);
    else
        ::SendMessage(m_FilePreview.m_hWnd, WM_VSCROLL, MAKEWPARAM(SB_LINEDOWN, 0), NULL);

    bHandled = FALSE;

    return 0;
}

LRESULT CViewDlg::OnOK(WORD /*wNotifyCode*/, WORD wID, HWND /*hWndCtl*/, BOOL& /*bHandled*/)
{
    ShowWindow(SW_HIDE);

    return 0;
}

LRESULT CViewDlg::OnCancel(WORD /*wNotifyCode*/, WORD wID, HWND /*hWndCtl*/, BOOL& /*bHandled*/)
{
    ShowWindow(SW_HIDE);

    return 0;
}
